#! /bin/sh
#
# Utilty to create self-extracting tar.gz archives.
# The resulting archive is a file holding the tar.gz archive with
# a small Shell script stub that uncompresses the archive to a temporary
# directory and then executes a given script from withing that directory.
#
# Makeself home page: http://www.lokigames.com/~megastep/makeself/
#
# (C) Stphane Peter 1998
#
# This software is released under the terms of the GNU GPL
# Please read the license at http://www.gnu.org/copyleft/gpl.html
#

if [ $# -lt 4 ]; then
    echo $0: Not enough parameters.
    echo "Usage: $0 [archive dir] [file name] [label] [startup script] [args]"
    echo Do not forget to give a fully qualified startup script name 
    echo "(i.e. with a ./ prefix if inside the archive)."
    exit 1
fi

archdir=$1
archname=$2

# The following is the shell script stub code
echo '#! /bin/sh' > $archname
echo label=\"$3\" >> $archname
echo script=$4 >> $archname
shift 4
echo scriptargs=\"$*\" >> $archname

cat << EOF >> $archname
skip=24
if [ "\$1" = "-keep" ]; then echo "Creating directory $archdir"; tmpdir=$archdir;
else tmpdir="/tmp/selfgz\$\$"; fi
location=\`pwd\`
echo=echo; [ -x /usr/ucb/echo ] && echo=/usr/ucb/echo
mkdir \$tmpdir || {
        echo 'Cannot create a temporary directory' >&2
        exit 1
}
\$echo -n Uncompressing \$label
cd \$tmpdir
[ "\$1" = "-keep" ] || trap 'cd /tmp; /bin/rm -rf \$tmpdir; exit \$res'
if ( (cd \$location; tail +\$skip \$0; ) | gzip -cd | tar xvof - | \
 (while read a; do \$echo -n .; done; echo; )) 2> /dev/null; then
    \$script \$scriptargs; res=\$?
    [ "\$1" = "-keep" ] || ( cd /tmp; /bin/rm -rf \$tmpdir; )
else
  echo Cannot decompress \$0; exit 1
fi;
exit \$res
EOF

# Append the tar.gz data after the stub
echo Adding files to archive named \"$archname\"...
(cd $archdir; tar cvf - *| gzip -9c ) >> $archname && chmod +x $archname && \
echo Self-extractible archive successfully created.
